@@ -117,10 +117,15 @@ def domain_is_false_positive(domain: bytes) -> bool:
     # Common variable roots
     root_fpos = {
         b"abbrev",
+        b"activate",
         b"adodb",
         b"agent",
         b"algorithm",
         b"alias",
+        b"analytic",
+        b"analytics",
+        b"append",
+        b"appendreplace",
         b"aquota",
         b"arena",
         b"arenastring",
@@ -129,6 +134,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"ascii",
         b"at",
         b"attrtable",
+        b"authentication",
         b"barrier",
         b"base64",
         b"basetype",
@@ -138,6 +144,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"bignum",
         b"bind",
         b"blake2",
+        b"build",
         b"button",
         b"bytestream",
         b"cgroup",
@@ -145,13 +152,17 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"check",
         b"city",
         b"clause",
+        b"clean",
         b"clock",
+        b"code-of-conduct",
         b"colors",
         b"column",
         b"common",
+        b"compile",
         b"conditions",
         b"config",
         b"constructor",
+        b"context",
         b"contributing",
         b"conversion",
         b"convert",
@@ -174,11 +185,16 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"descripters",
         b"destructible",
         b"di",
+        b"div",
         b"division",
         b"double-to-string",
         b"downcalls",
         b"duration",
         b"ecdh",
+        b"ecos",
+        b"el",
+        b"electron",
+        b"elem",
         b"email",
         b"emergency",
         b"enduser",
@@ -187,6 +203,9 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"escape",
         b"escaping",
         b"event",
+        b"eventstudy",
+        b"example",
+        b"examples",
         b"exit",
         b"expr",
         b"extention",
@@ -208,6 +227,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"function",
         b"functionprototype",
         b"futex",
+        b"gettingstarted",
         b"glob",
         b"global",
         b"globals",
@@ -277,12 +297,22 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"numbers",
         b"obj",
         b"object",
+        b"offset",
+        b"offsets",
+        b"og",
         b"once",
+        b"option",
+        b"options",
+        b"original",
+        b"originalresults",
         b"org",
         b"os",
         b"oshlnk",
         b"ostringstream",
         b"output",
+        b"package",
+        b"packagejson",
+        b"parentoffset",
         b"parser",
         b"path",
         b"paths",
@@ -295,6 +325,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"poweroff",
         b"printable",
         b"process",
+        b"profile",
         b"program",
         b"property",
         b"proto",
@@ -305,19 +336,24 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"randen",
         b"random",
         b"reader",
+        b"readme",
         b"reboot",
         b"refcount",
         b"remote",
         b"remote-fs",
         b"remote-fs-pre",
+        b"repository",
         b"rescue",
         b"response",
+        b"restore",
         b"result",
+        b"results",
         b"ribbon",
         b"roots",
         b"rpcbind",
         b"runtests",
         b"rvalue",
+        b"security",
         b"sequence",
         b"service",
         b"set",
@@ -334,13 +370,18 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"simple",
         b"socket",
         b"sockets",
+        b"source",
+        b"spec",
         b"spinlock",
+        b"src",
         b"stack",
         b"stacktrace",
         b"startup",
+        b"startvscode",
         b"state",
         b"status",
         b"statusor",
+        b"str",
         b"strcat",
         b"strerror",
         b"string",
@@ -378,6 +419,7 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"tracing",
         b"track",
         b"trie",
+        b"tween",
         b"ui",
         b"uint16",
         b"uint32",
@@ -417,16 +459,22 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"cat",
         b"cc",
         b"center",
+        b"chrome",
+        b"ci",
         b"city",
         b"click",
         b"country",
         b"data",
         b"day",
+        b"delta",
         b"direct",
+        b"do",
         b"email",
         b"events",
         b"exposed",
         b"fail",
+        b"foo",
+        b"fun",
         b"global",
         b"green",
         b"group",
@@ -438,9 +486,11 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"is",
         b"it",
         b"lat",
+        b"lb",
         b"link",
         b"map",
         b"md",
+        b"mk",
         b"mobile",
         b"ms",
         b"marketing",
@@ -462,6 +512,8 @@ def domain_is_false_positive(domain: bytes) -> bool:
         b"run",
         b"save",
         b"search",
+        b"secure",
+        b"security",
         b"services",
         b"sh",
         b"shell",
